@@ -11,23 +11,7 @@ warnings.filterwarnings("ignore")
 def install(package):
     subprocess.check_call([sys.executable, "-m", "pip", "install", package])
 
-install("networkx==2.2")
-install("pandas")
-install("numpy")
-install ("urllib3")
-install("requests")
-install("matplotlib")
-install("tweepy")
-install("nltk")
-install("textblob")
-install("fastdtw")
-install ("spicy")
-install("cdlib")
-install("community")
-install("python-igraph")
-install("leidenalg")
-install("cdlib")
-#install("infomap==1.0.0b54")
+
 
 ##----------------------------------------------IMPORTS---------------------------------------------------------------------------#	
 import json
@@ -176,7 +160,7 @@ def buildingGraph(df_graph):
 
 
 def girvanNewman_alg(node_list,df_graph):
-    DiG = building_DiGraph(node_list,df_graph,alg="str")
+    DiG = building_DiGraph(node_list,df_graph,"str")
     communities_generator = community.girvan_newman(DiG)
     top_level_communities = next(communities_generator)
     next_level_communities = next(communities_generator)
@@ -203,7 +187,7 @@ def louvain_alg(node_list,df_graph):
 
 def leiden_alg (df_graph):
     df_graph, node_list = node_list_conversion(df_graph)
-    DiG = building_DiGraph(list(node_list["id"]),df_graph,alg="num")
+    DiG = building_DiGraph(list(node_list["id"]),df_graph,"num")
     coms = algorithms.leiden(DiG)
     data = pd.DataFrame()
     data["id"]=  coms.communities
@@ -246,11 +230,11 @@ def graph_algoritm_selected(df_graph,selection,node_list):
     print(type(selection))
     print(selection)
     if(selection =="1"):
-        df_algComu = girvanNewman_alg(node_list,df_graph,alg="str")
+        df_algComu = girvanNewman_alg(node_list,df_graph)
     elif(selection =="2"):
-        df_algComu = leiden_alg(df_graph,alg="num")
+        df_algComu = leiden_alg(df_graph)
     elif(selection =="3"):
-        df_algComu = infMap_alg(df_graph, alg="num")
+        df_algComu = infMap_alg(df_graph)
     else:#default
         if(len_nodeList < 1000):
             df_algComu = girvanNewman_alg(node_list,df_graph)
@@ -268,12 +252,12 @@ def building_DiGraph(node_list, df_graph, alg_type):
     DiG.add_nodes_from(node_list)
     for i in range(len(df_graph)):
         if alg_type=="str":            
-            if(df['screen_name_mention'].iloc[i] !="Empty"):
-                DiG.add_edge(df['screen_name'].iloc[i],df['screen_name_mention'].iloc[i])
+            if(df_graph['screen_name_mention'].iloc[i] !="Empty"):
+                DiG.add_edge(df_graph['screen_name'].iloc[i],df_graph['screen_name_mention'].iloc[i])
         else:
             #Second condition for delete empty when we convert screen_name to numbers for specific algorithms
-            if(df["screen_name_mention"].iloc[i] != len(node_list)):
-                DiG.add_edge(df['screen_name_num'].iloc[i],df['screen_name_mention_num'].iloc[i])
+            if(df_graph["screen_name_mention"].iloc[i] != len(node_list)):
+                DiG.add_edge(df_graph['screen_name_num'].iloc[i],df_graph['screen_name_mention_num'].iloc[i])
     return DiG
     
 
